#include "demo.h"
#include "demo_legacy.h"
#include "demarathon.h"

#include <stdio.h>
#include <string.h>

#define xstr(s) str(s)
#define str(s) #s

#define MAX_DEMOS 200

struct marathon marathon[MAX_DEMOS];

static void print_help(void);

int main(int argc, char *argv[])
{
  char *inname, *pakname;
  int ret;
  int democount;
  demo *indemo;

  printf("demarathon version " xstr(DEMARATHON_VERSION) " by Mandel\n");
  fflush(stdout);
  memset(marathon, 0, MAX_DEMOS * sizeof(struct marathon));

  if (argc < 2 ||
      strcmp(argv[1], "-h") == 0 ||
      strcmp(argv[1], "--help") == 0)
  {
    print_help();
    return -1;
  }

  // get in and out filenames
  inname = argv[1];
  if (argc > 2) {
    pakname = argv[2];
  }
  else {
    pakname = "pak0.pak";
  }

  // read demo
  ret = read_demo(inname, &indemo);
  if (ret != DEMO_OK) {
    printf("error: %s\n", demo_error(ret));
    return ret;
  }

  // create marathon structure
  ret = make_marathon(indemo, marathon, MAX_DEMOS, &democount);
  if (ret != DEMARATHON_OK) {
    printf("error: %s\n", demarathon_error(ret));
    return ret;
  }
  printf("read %s\n", inname);
  fflush(stdout);

  // filter each demo
  ret = filter_demos(marathon, democount);
  if (ret != DEMARATHON_OK) {
    printf("error: %s\n", demarathon_error(ret));
    return ret;
  }
  printf("processed %d demos\n", democount);
  fflush(stdout);

  // make pak
  ret = make_pak(pakname, marathon, democount);
  if (ret != DEMARATHON_OK) {
    printf("error: %s\n", demarathon_error(ret));
    return ret;
  }
  printf("wrote %s\n", pakname);
  fflush(stdout);

  return 0;
}

static void print_help(void)
{
  printf("usage:\n");
  printf("demarathon <demo> [<pak>]\n");
  printf("\n");
  printf(" <demo>  file name of the demo file to convert\n");
  printf(" <pak>   pak file name to create. If not specified,\n"
         "         pak0.pak is used\n");
}
